
# senTM

Pronounced "sen-T-M". 

senTM is a lexical approach to sentiment analysis in Danish. The approach is inspired by the [afinn](https://github.com/fnielsen/afinn) package, but using the [Danish Sentiment Lexicon version 0.2 (2022-12-20)](https://github.com/dsldk/danish-sentiment-lexicon). 

The approach use the part-of-speech (POS) model from Spacy and then matches any tokens from the Danish Sentiment Lexicon. 

License: Same as [Danish Sentiment Lexicon version 0.2 (2022-12-20)](https://github.com/dsldk/danish-sentiment-lexicon): CC-BY-SA 4.0 International https://creativecommons.org/licenses/by-sa/4.0/